Resources — cq-studio 0.8 documentation

# Resources

## Website / documentation

The project’s documentation and website, such as it is, is hosted at https://pyropus.ca/docs/cq-studio/.

## Repository

The project’s software repository is hosted on Github, at https://github.com/ccazabon/cq-studio/.

## Mailing List

I typically have mailing lists for my projects that are used by others. If there is interest in `cq-studio` I may create one.

## Contact

If you need to contact me personally, you can email me at `charlesc-software-cqs` at `pyropus.ca`. Please note that I probably won’t be able to spend much time on private technical support - that’s why I normally have mailing lists and archives, so that those resources are available to other users in the future.